@@ -621,7 +621,7 @@ def run_cmd_onlyenv():
         ).replace(" ", "_")
 
         def is_english_only(s):
-            return bool(re.match("^[A-Za-z0-9_#", s))
+            return bool(re.match("^[A-Za-z0-9_#]+$", s))
 
         if is_english_only(_name):
             _name = _name[:10]
@@ -656,7 +656,8 @@ def run_cmd_onlyenv():
     _name_env = create_name_env()
     print(f"your env name is `{bcolors.OKGREEN}{_name_env}{bcolors.ENDC}`")
     create_virtualenv(_name_env)
-    create_setting_vscode(_name_env)
+    dir_name_only = os.path.basename(os.getcwd()) # get name dir main
+    create_setting_vscode(dir_name_only)
 
 
 def run_cmd_clean():
